ll-orasql
=========

Utilities for working with cx_Oracle__.

__ http://www.python.net/crew/atuining/cx_Oracle/

For documentation read the source.

For requirements and installation instructions read ``INSTALL.rst``.

For a list of new features and bugfixes read ``NEWS.rst``.

For the license read ``orasql.py``.

ll-orasql is available from ftp://ftp.livinglogic.de/pub/livinglogic/orasql/

Web pages can be found at http://www.livinglogic.de/Python/orasql/

-- Walter Dörwald <walter@livinglogic.de>
